import React from 'react'
import { has, get } from 'lodash'
import { Icon } from '@pubsweet/ui'
import styled, { css } from 'styled-components'

const positionHelper = css`
  position: ${props =>
    has(props, 'top', 'bottom', 'left', 'right') ? 'absolute' : 'initial'};
  top: ${props => (has(props, 'top') ? `${get(props, 'top')}px` : 'unset')};
  bottom: ${props =>
    has(props, 'bottom') ? `${get(props, 'bottom')}px` : 'unset'};
  left: ${props => (has(props, 'left') ? `${get(props, 'left')}px` : 'unset')};
  right: ${props =>
    has(props, 'right') ? `${get(props, 'right')}px` : 'unset'};
`

const IconButton = styled.div`
  align-items: center;
  cursor: pointer;
  display: flex;
  justify-content: center;
  &:hover {
    opacity: 0.7;
  }

  ${positionHelper};
`

export default ({ icon, onClick, iconSize = 3, ...props }) => (
  <IconButton onClick={onClick} {...props}>
    <Icon size={iconSize} {...props}>
      {icon}
    </Icon>
  </IconButton>
)
