import React from 'react'
import { H3, H4 } from '@pubsweet/ui'
import styled from 'styled-components'
import { th, darken } from '@pubsweet/ui-toolkit'

import Tag from './Tag'
import Text from './Text'
import Row from './gridItems/Row'
import IconButton from './IconButton'
import AuthorTagList from './AuthorTagList'

const ManuscriptCard = ({
  fragment: { authors = [], metadata: { title, journal, type } },
  collection: { visibleStatus = 'Draft', handlingEditor, customId },
}) => (
  <Root>
    <MainContainer>
      <Row alignItems="center" justify="space-between">
        <H3>{title}</H3>
        <Tag status>{visibleStatus}</Tag>
      </Row>
      <Row alignItems="center" justify="flex-start">
        <AuthorTagList authors={authors} />
      </Row>
      <Row alignItems="center" justify="flex-start">
        <Text customId>{`ID ${customId}`}</Text>
        <Text secondary>Submitted on 03.07.2018</Text>
        <H4>{type}</H4>
        <Text secondary>{journal}</Text>
      </Row>
      <Row alignItems="center" justify="flex-start">
        <H4>Handling editor</H4>
        <Text>{handlingEditor.name}</Text>
        <H4>Reviewer Reports</H4>
        <Text>0 invited</Text>
      </Row>
    </MainContainer>
    <SideNavigation>
      <IconButton icon="chevron-right" iconSize={2} />
    </SideNavigation>
  </Root>
)

export default ManuscriptCard

// #region styles
const MainContainer = styled.div`
  justify-content: flex-start;
  display: flex;
  flex: 1;
  flex-direction: column;
  padding: calc(${th('gridUnit')} * 2);
  padding-bottom: ${th('gridUnit')};

  ${Row} {
    margin-bottom: ${th('gridUnit')};

    &:nth-child(3) {
      ${Text} {
        margin-right: ${th('gridUnit')};
      }

      ${H4} {
        margin-right: ${th('gridUnit')};
      }
    }

    &:last-child {
      ${H4} {
        margin-right: ${th('gridUnit')};
      }

      ${Text} {
        margin-right: calc(${th('gridUnit')} * 5);
      }
    }
  }
`

const SideNavigation = styled.div`
  align-items: center;
  background-color: ${th('colorBackgroundHue')};
  border-top-right-radius: ${th('borderRadius')};
  border-bottom-right-radius: ${th('borderRadius')};
  cursor: pointer;
  display: flex;
  width: calc(${th('gridUnit')} * 5 / 2);

  &:hover {
    background-color: ${darken('colorBackgroundHue', 0.05)};
  }
`

const Root = styled.div`
  border-radius: ${th('borderRadius')};
  box-shadow: ${th('boxShadow')};
  display: flex;

  &:hover {
    box-shadow: ${th('dashboardCard.hoverShadow')};
  }

  ${H3} {
    margin: 0;
    margin-bottom: ${th('gridUnit')};
  }

  ${H4} {
    margin: 0;
  }
`
// #endregion
